package at.xaxa.gamelibraryapp.ui

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.requiredHeight
import androidx.compose.foundation.layout.requiredWidth
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.List
import androidx.compose.material.icons.filled.Add
import androidx.compose.material.icons.outlined.Delete
import androidx.compose.material.icons.outlined.Edit
import androidx.compose.material3.FilledTonalButton
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.NavigationBarItem
import androidx.compose.material3.OutlinedButton
import androidx.compose.material3.OutlinedCard
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.em
import androidx.compose.ui.unit.sp
import androidx.navigation.NavType
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.currentBackStackEntryAsState
import androidx.navigation.compose.rememberNavController
import androidx.navigation.navArgument
import at.xaxa.gamelibraryapp.R
import coil3.compose.AsyncImage
import java.time.format.TextStyle

enum class DemoRoutes(val route: String) {
    List("list"),
    Add("add"),
    Detail("task/{taskId}")
}

@Composable
fun LibraryApp(modifier: Modifier = Modifier) {
    val navController = rememberNavController()

    Scaffold(
        bottomBar = {
            androidx.compose.material3.NavigationBar {
                NavigationBarItem(
                    icon = { Icon(Icons.AutoMirrored.Filled.List, contentDescription = "List") },
                    label = { Text("List") },
                    selected = navController.currentBackStackEntryAsState().value?.destination?.route == "list",
                    onClick = { navController.navigate(DemoRoutes.List.route) }
                )
                NavigationBarItem(
                    icon = { Icon(Icons.Default.Add, contentDescription = "Add") },
                    label = { Text("Add") },
                    selected = navController.currentBackStackEntryAsState().value?.destination?.route == "add",
                    onClick = { navController.navigate(DemoRoutes.Add.route) }
                )
            }
        }
    ) { innerPadding ->
        NavHost(
            navController = navController,
            startDestination = DemoRoutes.List.route,
            modifier = Modifier.padding(innerPadding)
        ) {
            composable(DemoRoutes.List.route){
                // screen
            }
            composable(DemoRoutes.Add.route) {
                // screen
            }
            composable(
                route = DemoRoutes.Detail.route,
                arguments = listOf(navArgument("taskId") {
                    type = NavType.IntType
                })
            ) {
                // screen
            }
        }
    }
}


@Composable
fun HorizontalCard(modifier: Modifier = Modifier, title: String, details: String) {
    Surface(
        modifier = modifier
            .requiredWidth(360.dp)
            .requiredHeight(80.dp)
            .clip(RoundedCornerShape(12.dp))
    ) {
        Row(modifier = Modifier.fillMaxSize()) {
            LayoutMediaText(modifier = Modifier.weight(1f), title, details)
            ShowPicture(modifier = Modifier.weight(0.5f))
        }
    }
}


@Composable
fun LayoutMediaText(modifier: Modifier = Modifier, title: String, details: String) {
    Row(
        verticalAlignment = Alignment.CenterVertically,
        modifier = modifier
            .fillMaxWidth()
            .clip(shape = RoundedCornerShape(12.dp))
    ) {
        Row(
            horizontalArrangement = Arrangement.spacedBy(16.dp, Alignment.Start),
            verticalAlignment = Alignment.CenterVertically,
            modifier = Modifier
                .fillMaxSize()
                .weight(weight = 1f)
                .padding(all = 16.dp)
        ) {
            Column(
                verticalArrangement = Arrangement.spacedBy(4.dp, Alignment.Top),
                modifier = Modifier
                    .fillMaxWidth()
            ) {
                Text(
                    text = title,
                    color = Color.DarkGray,
                    lineHeight = 1.5.em,
                    style = androidx.compose.ui.text.TextStyle(
                        fontSize = 16.sp,
                        fontWeight = FontWeight.Medium,
                        letterSpacing = 0.15.sp
                    ),
                    modifier = Modifier
                        .fillMaxWidth())
                Text(
                    text = details,
                    color = Color.DarkGray,
                    lineHeight = 1.43.em,
                    style = androidx.compose.ui.text.TextStyle(
                        fontSize = 14.sp,
                        letterSpacing = 0.25.sp
                    ),
                    modifier = Modifier
                        .fillMaxWidth())
            }
        }
    }
}

@Composable
fun ShowPicture(modifier: Modifier = Modifier) {
    Surface(
        shape = RoundedCornerShape(12.dp),
        color = Color(0xfffef7ff),
        modifier = modifier
            .clip(shape = RoundedCornerShape(12.dp))
    ) {
        //Display Image here
        AsyncImage(
            model = "https://media.rawg.io/media/games/b7f/b7ffc4c4776e61eca19d36d3c227f89a.jpg",
            contentDescription = "Translated description of what the image contains",
            Modifier.fillMaxHeight()
        )
    }
}

@Preview(widthDp = 360, heightDp = 80)
@Composable
private fun HorizontalCardPreview() {
    HorizontalCard(Modifier, "Uncharted 3", "Action Adventure, 2011")
}